@@ -1,7 +1,7 @@
 import simple_gpg.simple_gpg
 import sys
 
-sys.setrecursionlimit(10**5)
+sys.setrecursionlimit(1100)
 
 def main():
     simple_gpg.simple_gpg.main()
